==================
PassTheSecret Core
==================

PassTheSecret Core is the heart of the different deployment methods for
PassTheSecret. The Core provides all encryption functionality and
interaction with the back-end data stores.

License
-------
PassTheSecret Core is free software: you can redistribute it and/or modify it under the terms of the GNU General Public License as published by the Free Software Foundation, either version 3 of the License, or (at your option) any later version.

PassTheSecret Core is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License for more details.

You should have received a copy of the GNU General Public License along with PassTheSecret Core.  If not, see <http://www.gnu.org/licenses/>.
